package cmd

import (
	"os"
	"time"

	"github.com/spf13/cobra"
	"lab.libreho.st/libre.sh/docker/rc-apps-mgr/internal"
)

var host, username, password string
var uninstall, force bool

var rootCmd = &cobra.Command{
	Use:   "rc-apps-mgr [flags] [folder|files...]",
	Short: "A cli to manage RC apps without the marketplace",
	Args:  cobra.MinimumNArgs(1),
	Run: func(cmd *cobra.Command, args []string) {
		apps := internal.LoadAppsFromArgs(args)
		rc := internal.NewRC(host, username, password)
		rc.SetAppDevMode(true)
		time.Sleep(time.Second)
		for _, app := range apps {
			if rc.IsInstalled(app) {
				rc.Update(app)
			} else {
				rc.Install(app)
			}
		}
		if uninstall && (len(apps) != 0 || force) {
			installed := rc.List()
			for _, id := range installed {
				app := internal.GetApp(apps, id)
				if app == nil {
					rc.Uninstall(id)
				}
			}
		}
		rc.SetAppDevMode(false)
	},
}

func Execute() {
	cobra.CheckErr(rootCmd.Execute())
}

func init() {
	rootCmd.Flags().StringVar(&host, "host", os.Getenv("HOST"), `host [env "HOST"]`)
	rootCmd.Flags().StringVar(&username, "username", os.Getenv("USERNAME"), `username [env "USERNAME"]`)
	rootCmd.Flags().StringVar(&password, "password", os.Getenv("PASSWORD"), `password [env "PASSWORD"]`)
	rootCmd.Flags().BoolVar(&uninstall, "uninstall", false, `uninstall apps that are not listed`)
	rootCmd.Flags().BoolVar(&force, "force", false, `force to uninstall when no app is listed`)
}
