package internal

import (
	"archive/zip"
	"io"
	"log"
	"os"
	"path/filepath"
	"strings"

	"github.com/tidwall/gjson"
)

type App struct {
	Filename string
	ID       string
	Name     string
}

func toApp(path string) App {
	r, err := zip.OpenReader(path)
	ExitOnError(err)
	defer r.Close()

	f, err := r.Open("app.json")
	ExitOnError(err)
	defer f.Close()

	data, err := io.ReadAll(f)
	ExitOnError(err)
	id := gjson.GetBytes(data, "id").String()
	if id == "" {
		log.Fatalf("archive %s has no id in app.json\n", path)
	}
	name := gjson.GetBytes(data, "nameSlug").String()

	return App{Filename: path, ID: id, Name: name}
}

func GetApp(apps []App, id string) *App {
	for _, app := range apps {
		if app.ID == id {
			return &app
		}
	}
	return nil
}

func LoadAppsFromArgs(args []string) []App {
	apps := []App{}
	for _, arg := range args {
		info, err := os.Stat(arg)
		ExitOnError(err)
		if info.IsDir() {
			entries, err := os.ReadDir(arg)
			ExitOnError(err)
			for _, entry := range entries {
				if !entry.IsDir() && isZip(entry.Name()) {
					app := toApp(filepath.Join(info.Name(), entry.Name()))
					apps = append(apps, app)
				}
			}
		} else {
			if !isZip(info.Name()) {
				log.Fatal("only folders or zip files are accepted")
			}
			app := toApp(info.Name())
			apps = append(apps, app)
		}
	}
	return apps
}

func isZip(path string) bool {
	return strings.HasSuffix(path, ".zip")
}
